## $Id: interfaces.py 15011 2018-05-17 09:01:49Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##

import zope.i18nmessageid
from zope import schema
from zc.sourcefactory.basic import BasicSourceFactory
from waeup.kofa.interfaces import (SimpleKofaVocabulary,
    ISessionConfiguration, academic_sessions_vocab)

_ = MessageFactory = zope.i18nmessageid.MessageFactory('kofacustom.edopoly')

class ICustomSessionConfiguration(ISessionConfiguration):
    """A session configuration object.
    """

    # Base fees, do not remove.

    clearance_fee = schema.Float(
        title = _(u'Acceptance Fee'),
        default = 0.0,
        required = False,
        )

    booking_fee = schema.Float(
        title = _(u'Bed Booking Fee'),
        default = 0.0,
        required = False,
        )

    maint_fee = schema.Float(
        title = _(u'Rent (fallback)'),
        default = 0.0,
        required = False,
        )

    # Additional fees in custom package add here

    logbook_fee = schema.Float(
        title = _(u'Logbook Fee'),
        default = 0.0,
        required = False,
        )

    ict_entre_fee = schema.Float(
        title = _(u'ICT & Entrepreneur Fee'),
        default = 0.0,
        required = False,
        )

    def getSessionString():
        """Returns the session string from the vocabulary.
        """


class ICustomSessionConfigurationAdd(ICustomSessionConfiguration):
    """A session configuration object in add mode.
    """

    academic_session = schema.Choice(
        title = _(u'Academic Session'),
        source = academic_sessions_vocab,
        default = None,
        required = True,
        readonly = False,
        )

ICustomSessionConfigurationAdd[
    'academic_session'].order =  ICustomSessionConfiguration[
    'academic_session'].order